# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from uuid import UUID
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python


class Snapshot(BaseModel):
    """
    Snapshot
    """  # noqa: E501

    id: UUID
    files_new: Optional[Annotated[int, Field(strict=True, ge=0)]] = 0
    files_changed: Optional[Annotated[int, Field(strict=True, ge=0)]] = 0
    files_unmodified: Optional[Annotated[int, Field(strict=True, ge=0)]] = 0
    dirs_new: Optional[Annotated[int, Field(strict=True, ge=0)]] = 0
    dirs_changed: Optional[Annotated[int, Field(strict=True, ge=0)]] = 0
    dirs_unmodified: Optional[Annotated[int, Field(strict=True, ge=0)]] = 0
    data_blobs: Optional[Annotated[int, Field(strict=True, ge=0)]] = 0
    tree_blobs: Optional[Annotated[int, Field(strict=True, ge=0)]] = 0
    data_added: Optional[Annotated[int, Field(strict=True, ge=0)]] = 0
    data_added_packed: Optional[Annotated[int, Field(strict=True, ge=0)]] = 0
    total_files_processed: Optional[Annotated[int, Field(strict=True, ge=0)]] = 0
    total_bytes_processed: Optional[Annotated[int, Field(strict=True, ge=0)]] = 0
    total_duration: Optional[
        Union[Annotated[float, Field(strict=True, ge=0.0)], Annotated[int, Field(strict=True, ge=0)]]
    ] = 0
    snapshot_id: Optional[StrictStr] = None
    backup_paths: Optional[List[StrictStr]] = None
    __properties: ClassVar[List[str]] = [
        "id",
        "files_new",
        "files_changed",
        "files_unmodified",
        "dirs_new",
        "dirs_changed",
        "dirs_unmodified",
        "data_blobs",
        "tree_blobs",
        "data_added",
        "data_added_packed",
        "total_files_processed",
        "total_bytes_processed",
        "total_duration",
        "snapshot_id",
        "backup_paths",
    ]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Snapshot from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if snapshot_id (nullable) is None
        # and model_fields_set contains the field
        if self.snapshot_id is None and "snapshot_id" in self.model_fields_set:
            _dict["snapshot_id"] = None

        # set to None if backup_paths (nullable) is None
        # and model_fields_set contains the field
        if self.backup_paths is None and "backup_paths" in self.model_fields_set:
            _dict["backup_paths"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Snapshot from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "id": obj.get("id"),
                "files_new": obj.get("files_new") if obj.get("files_new") is not None else 0,
                "files_changed": obj.get("files_changed") if obj.get("files_changed") is not None else 0,
                "files_unmodified": obj.get("files_unmodified") if obj.get("files_unmodified") is not None else 0,
                "dirs_new": obj.get("dirs_new") if obj.get("dirs_new") is not None else 0,
                "dirs_changed": obj.get("dirs_changed") if obj.get("dirs_changed") is not None else 0,
                "dirs_unmodified": obj.get("dirs_unmodified") if obj.get("dirs_unmodified") is not None else 0,
                "data_blobs": obj.get("data_blobs") if obj.get("data_blobs") is not None else 0,
                "tree_blobs": obj.get("tree_blobs") if obj.get("tree_blobs") is not None else 0,
                "data_added": obj.get("data_added") if obj.get("data_added") is not None else 0,
                "data_added_packed": obj.get("data_added_packed") if obj.get("data_added_packed") is not None else 0,
                "total_files_processed": obj.get("total_files_processed")
                if obj.get("total_files_processed") is not None
                else 0,
                "total_bytes_processed": obj.get("total_bytes_processed")
                if obj.get("total_bytes_processed") is not None
                else 0,
                "total_duration": obj.get("total_duration") if obj.get("total_duration") is not None else 0,
                "snapshot_id": obj.get("snapshot_id"),
                "backup_paths": obj.get("backup_paths"),
            }
        )
        return _obj



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.page_backup_plan_error import PageBackupPlanError


class TestPageBackupPlanError(unittest.TestCase):
    """PageBackupPlanError unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PageBackupPlanError:
        """Test PageBackupPlanError
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `PageBackupPlanError`
        """
        model = PageBackupPlanError()
        if include_optional:
            return PageBackupPlanError(
                page = 56,
                per_page = 56,
                total_items = 56,
                total_pages = 56,
                items = [
                    cybee_sdk.api.models.backup_plan_error.BackupPlanError(
                        id = '', 
                        backup_run_id = '', 
                        error = { }, 
                        during = '', 
                        item = '', )
                    ]
            )
        else:
            return PageBackupPlanError(
                page = 56,
                per_page = 56,
                total_items = 56,
                items = [
                    cybee_sdk.api.models.backup_plan_error.BackupPlanError(
                        id = '', 
                        backup_run_id = '', 
                        error = { }, 
                        during = '', 
                        item = '', )
                    ],
        )
        """

    def testPageBackupPlanError(self):
        """Test PageBackupPlanError"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from uuid import UUID
from cybee_sdk.api.models.repository_status_enum import RepositoryStatusEnum
from cybee_sdk.api.models.restic_version_enum import ResticVersionEnum
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python


class Repository(BaseModel):
    """
    Repository
    """  # noqa: E501

    id: UUID
    name: StrictStr
    slug: StrictStr
    description: Optional[StrictStr] = None
    status: RepositoryStatusEnum
    storage_destination_id: UUID
    created_at: datetime
    updated_at: datetime
    version: ResticVersionEnum
    __properties: ClassVar[List[str]] = [
        "id",
        "name",
        "slug",
        "description",
        "status",
        "storage_destination_id",
        "created_at",
        "updated_at",
        "version",
    ]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Repository from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict["description"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Repository from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "id": obj.get("id"),
                "name": obj.get("name"),
                "slug": obj.get("slug"),
                "description": obj.get("description"),
                "status": obj.get("status"),
                "storage_destination_id": obj.get("storage_destination_id"),
                "created_at": obj.get("created_at"),
                "updated_at": obj.get("updated_at"),
                "version": obj.get("version"),
            }
        )
        return _obj



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.api.notification_api import NotificationApi


class TestNotificationApi(unittest.TestCase):
    """NotificationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = NotificationApi()

    def tearDown(self) -> None:
        pass

    def test_create_channel_notification_channels_channel_type_post(self) -> None:
        """Test case for create_channel_notification_channels_channel_type_post

        Create Channel
        """
        pass

    def test_create_router_notification_routers_post(self) -> None:
        """Test case for create_router_notification_routers_post

        Create Router
        """
        pass

    def test_create_template_notification_templates_post(self) -> None:
        """Test case for create_template_notification_templates_post

        Create Template
        """
        pass

    def test_delete_channel_notification_channels_channel_id_delete(self) -> None:
        """Test case for delete_channel_notification_channels_channel_id_delete

        Delete Channel
        """
        pass

    def test_delete_router_notification_routers_router_id_delete(self) -> None:
        """Test case for delete_router_notification_routers_router_id_delete

        Delete Router
        """
        pass

    def test_delete_template_notification_templates_template_id_delete(self) -> None:
        """Test case for delete_template_notification_templates_template_id_delete

        Delete Template
        """
        pass

    def test_list_channels_notification_channels_get(self) -> None:
        """Test case for list_channels_notification_channels_get

        List Channels
        """
        pass

    def test_list_routers_notification_routers_get(self) -> None:
        """Test case for list_routers_notification_routers_get

        List Routers
        """
        pass

    def test_list_templates_notification_templates_get(self) -> None:
        """Test case for list_templates_notification_templates_get

        List Templates
        """
        pass

    def test_update_router_notification_routers_router_id_patch(self) -> None:
        """Test case for update_router_notification_routers_router_id_patch

        Update Router
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.api.storage_account_api import StorageAccountApi


class TestStorageAccountApi(unittest.TestCase):
    """StorageAccountApi unit test stubs"""

    def setUp(self) -> None:
        self.api = StorageAccountApi()

    def tearDown(self) -> None:
        pass

    def test_create_storage_account_storage_storage_account_post(self) -> None:
        """Test case for create_storage_account_storage_storage_account_post

        Create Storage Account
        """
        pass

    def test_delete_storage_account_storage_storage_account_storage_account_id_delete(self) -> None:
        """Test case for delete_storage_account_storage_storage_account_storage_account_id_delete

        Delete Storage Account
        """
        pass

    def test_get_storage_account_storage_storage_account_storage_account_id_get(self) -> None:
        """Test case for get_storage_account_storage_storage_account_storage_account_id_get

        Get Storage Account
        """
        pass

    def test_list_storage_account_storage_storage_account_get(self) -> None:
        """Test case for list_storage_account_storage_storage_account_get

        List Storage Account
        """
        pass

    def test_update_storage_account_storage_storage_account_storage_account_id_put(self) -> None:
        """Test case for update_storage_account_storage_storage_account_storage_account_id_put

        Update Storage Account
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.api.plans_backup_api import PlansBackupApi


class TestPlansBackupApi(unittest.TestCase):
    """PlansBackupApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PlansBackupApi()

    def tearDown(self) -> None:
        pass

    def test_assign_backup_plan_agent_plan_backup_plan_id_assign_agent_agent_id_post(self) -> None:
        """Test case for assign_backup_plan_agent_plan_backup_plan_id_assign_agent_agent_id_post

        Assign Backup Plan Agent
        """
        pass

    def test_assign_backup_plan_schedule_plan_backup_plan_id_assign_schedule_schedule_id_post(self) -> None:
        """Test case for assign_backup_plan_schedule_plan_backup_plan_id_assign_schedule_schedule_id_post

        Assign Backup Plan Schedule
        """
        pass

    def test_cancel_running_backup_plan_plan_backup_run_backup_plan_run_id_cancel_put(self) -> None:
        """Test case for cancel_running_backup_plan_plan_backup_run_backup_plan_run_id_cancel_put

        Cancel Running Backup Plan
        """
        pass

    def test_create_file_backup_plans_plan_backup_file_post(self) -> None:
        """Test case for create_file_backup_plans_plan_backup_file_post

        Create File Backup Plans
        """
        pass

    def test_create_image_backup_plans_plan_backup_image_post(self) -> None:
        """Test case for create_image_backup_plans_plan_backup_image_post

        Create Image Backup Plans
        """
        pass

    def test_delete_file_backup_plans_plan_backup_file_plan_id_delete(self) -> None:
        """Test case for delete_file_backup_plans_plan_backup_file_plan_id_delete

        Delete File Backup Plans
        """
        pass

    def test_delete_image_backup_plans_plan_backup_image_plan_id_delete(self) -> None:
        """Test case for delete_image_backup_plans_plan_backup_image_plan_id_delete

        Delete Image Backup Plans
        """
        pass

    def test_execute_file_backup_plan_plan_backup_file_plan_id_execute_post(self) -> None:
        """Test case for execute_file_backup_plan_plan_backup_file_plan_id_execute_post

        Execute File Backup Plan
        """
        pass

    def test_execute_image_backup_plan_plan_backup_image_plan_id_execute_post(self) -> None:
        """Test case for execute_image_backup_plan_plan_backup_image_plan_id_execute_post

        Execute Image Backup Plan
        """
        pass

    def test_get_running_plan_status_plan_backup_run_plan_run_id_status_get(self) -> None:
        """Test case for get_running_plan_status_plan_backup_run_plan_run_id_status_get

        Get Running Plan Status
        """
        pass

    def test_list_all_backup_history_error_plan_backup_history_error_get(self) -> None:
        """Test case for list_all_backup_history_error_plan_backup_history_error_get

        List All Backup History Error
        """
        pass

    def test_list_all_backup_history_plan_backup_history_get(self) -> None:
        """Test case for list_all_backup_history_plan_backup_history_get

        List All Backup History
        """
        pass

    def test_list_all_latest_backup_history_plan_backup_history_latest_get(self) -> None:
        """Test case for list_all_latest_backup_history_plan_backup_history_latest_get

        List All Latest Backup History
        """
        pass

    def test_list_file_backup_plans_plan_backup_file_get(self) -> None:
        """Test case for list_file_backup_plans_plan_backup_file_get

        List File Backup Plans
        """
        pass

    def test_list_image_backup_plans_plan_backup_image_get(self) -> None:
        """Test case for list_image_backup_plans_plan_backup_image_get

        List Image Backup Plans
        """
        pass

    def test_remove_backup_plan_agent_plan_backup_plan_id_remove_agent_agent_id_post(self) -> None:
        """Test case for remove_backup_plan_agent_plan_backup_plan_id_remove_agent_agent_id_post

        Remove Backup Plan Agent
        """
        pass

    def test_remove_backup_plan_schedule_plan_backup_plan_id_remove_schedule_schedule_id_post(self) -> None:
        """Test case for remove_backup_plan_schedule_plan_backup_plan_id_remove_schedule_schedule_id_post

        Remove Backup Plan Schedule
        """
        pass

    def test_update_file_backup_plans_plan_backup_file_plan_id_put(self) -> None:
        """Test case for update_file_backup_plans_plan_backup_file_plan_id_put

        Update File Backup Plans
        """
        pass

    def test_update_image_backup_plans_plan_backup_image_plan_id_put(self) -> None:
        """Test case for update_image_backup_plans_plan_backup_image_plan_id_put

        Update Image Backup Plans
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from cybee_sdk.api.models.global_restic_options import GlobalResticOptions
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python


class ResticRestore(BaseModel):
    """
    ResticRestore
    """  # noqa: E501

    global_options: GlobalResticOptions
    exclude: Optional[List[StrictStr]] = None
    include: Optional[List[StrictStr]] = None
    iexclude: Optional[List[StrictStr]] = None
    iinclude: Optional[List[StrictStr]] = None
    host: Optional[StrictStr] = None
    path: Optional[StrictStr] = None
    tag: Optional[List[StrictStr]] = None
    sparse: Optional[StrictBool] = False
    target: StrictStr
    verify: Optional[StrictBool] = False
    snapshot_id: StrictStr
    __properties: ClassVar[List[str]] = [
        "global_options",
        "exclude",
        "include",
        "iexclude",
        "iinclude",
        "host",
        "path",
        "tag",
        "sparse",
        "target",
        "verify",
        "snapshot_id",
    ]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ResticRestore from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of global_options
        if self.global_options:
            _dict["global_options"] = self.global_options.to_dict()
        # set to None if host (nullable) is None
        # and model_fields_set contains the field
        if self.host is None and "host" in self.model_fields_set:
            _dict["host"] = None

        # set to None if path (nullable) is None
        # and model_fields_set contains the field
        if self.path is None and "path" in self.model_fields_set:
            _dict["path"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ResticRestore from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "global_options": GlobalResticOptions.from_dict(obj["global_options"])
                if obj.get("global_options") is not None
                else None,
                "exclude": obj.get("exclude"),
                "include": obj.get("include"),
                "iexclude": obj.get("iexclude"),
                "iinclude": obj.get("iinclude"),
                "host": obj.get("host"),
                "path": obj.get("path"),
                "tag": obj.get("tag"),
                "sparse": obj.get("sparse") if obj.get("sparse") is not None else False,
                "target": obj.get("target"),
                "verify": obj.get("verify") if obj.get("verify") is not None else False,
                "snapshot_id": obj.get("snapshot_id"),
            }
        )
        return _obj



# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.api.storage_destination_api import StorageDestinationApi


class TestStorageDestinationApi(unittest.TestCase):
    """StorageDestinationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = StorageDestinationApi()

    def tearDown(self) -> None:
        pass

    def test_create_storage_destination_storage_storage_destination_post(self) -> None:
        """Test case for create_storage_destination_storage_storage_destination_post

        Create Storage Destination
        """
        pass

    def test_delete_storage_destination_storage_storage_destination_storage_destination_id_delete(self) -> None:
        """Test case for delete_storage_destination_storage_storage_destination_storage_destination_id_delete

        Delete Storage Destination
        """
        pass

    def test_get_storage_destination_storage_storage_destination_storage_destination_id_get(self) -> None:
        """Test case for get_storage_destination_storage_storage_destination_storage_destination_id_get

        Get Storage Destination
        """
        pass

    def test_list_storage_destination_storage_storage_destination_get(self) -> None:
        """Test case for list_storage_destination_storage_storage_destination_get

        List Storage Destination
        """
        pass

    def test_update_storage_destination_storage_storage_destination_storage_destination_id_patch(self) -> None:
        """Test case for update_storage_destination_storage_storage_destination_storage_destination_id_patch

        Update Storage Destination
        """
        pass


if __name__ == "__main__":
    unittest.main()



"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictStr, field_validator
from typing import Any, List, Optional
from typing_extensions import Annotated
from uuid import UUID
from cybee_sdk.api.models.agent_lock import AgentLock
from cybee_sdk.api.models.agent_update import AgentUpdate
from cybee_sdk.api.models.page_agent_info import PageAgentInfo
from cybee_sdk.api.models.page_unregistered_agent_info import PageUnregisteredAgentInfo

from cybee_sdk.api.api_client import ApiClient, RequestSerialized
from cybee_sdk.api.api_response import ApiResponse
from cybee_sdk.api.rest import RESTResponseType


class AgentsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_call
    def approve_agent_agent_agent_id_approve_post(
        self,
        agent_id: UUID,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Approve Agent

        # Approve agent  Register a previously **unknown** (unregistered) agent into the system. Once approved, the agent becomes a fully registered agent and starts appearing in `GET /agent/`.  By default the agent is approved for the **caller's own organization**. To approve the agent on behalf of a different organization, set the `Cbe-User-Org-Id` header to the target organization id.  **Endpoint**: `POST /agent/{agent_id}/approve/`  **Auth**: requires an authenticated user.  ## Path parameter - `agent_id` (uuid, required): Identifier of the unregistered agent to approve. See `GET /agent/unregistered/`.  ## Headers - `Cbe-User-Org-Id` (string, optional): Organization the agent should be approved for. Defaults to the caller's organization when omitted.  ## Response - `204 No Content`: The agent was approved and registered.  ### Example  ```http POST /agent/c85a857f-4d70-4099-b84f-a6b74ea999de/approve/ HTTP/1.1 Authorization: Bearer <access_token> Cbe-User-Org-Id: 123456789 ```

        :param agent_id: (required)
        :type agent_id: UUID
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._approve_agent_agent_agent_id_approve_post_serialize(
            agent_id=agent_id,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "204": None,
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def approve_agent_agent_agent_id_approve_post_with_http_info(
        self,
        agent_id: UUID,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Approve Agent

        # Approve agent  Register a previously **unknown** (unregistered) agent into the system. Once approved, the agent becomes a fully registered agent and starts appearing in `GET /agent/`.  By default the agent is approved for the **caller's own organization**. To approve the agent on behalf of a different organization, set the `Cbe-User-Org-Id` header to the target organization id.  **Endpoint**: `POST /agent/{agent_id}/approve/`  **Auth**: requires an authenticated user.  ## Path parameter - `agent_id` (uuid, required): Identifier of the unregistered agent to approve. See `GET /agent/unregistered/`.  ## Headers - `Cbe-User-Org-Id` (string, optional): Organization the agent should be approved for. Defaults to the caller's organization when omitted.  ## Response - `204 No Content`: The agent was approved and registered.  ### Example  ```http POST /agent/c85a857f-4d70-4099-b84f-a6b74ea999de/approve/ HTTP/1.1 Authorization: Bearer <access_token> Cbe-User-Org-Id: 123456789 ```

        :param agent_id: (required)
        :type agent_id: UUID
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._approve_agent_agent_agent_id_approve_post_serialize(
            agent_id=agent_id,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "204": None,
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def approve_agent_agent_agent_id_approve_post_without_preload_content(
        self,
        agent_id: UUID,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Approve Agent

        # Approve agent  Register a previously **unknown** (unregistered) agent into the system. Once approved, the agent becomes a fully registered agent and starts appearing in `GET /agent/`.  By default the agent is approved for the **caller's own organization**. To approve the agent on behalf of a different organization, set the `Cbe-User-Org-Id` header to the target organization id.  **Endpoint**: `POST /agent/{agent_id}/approve/`  **Auth**: requires an authenticated user.  ## Path parameter - `agent_id` (uuid, required): Identifier of the unregistered agent to approve. See `GET /agent/unregistered/`.  ## Headers - `Cbe-User-Org-Id` (string, optional): Organization the agent should be approved for. Defaults to the caller's organization when omitted.  ## Response - `204 No Content`: The agent was approved and registered.  ### Example  ```http POST /agent/c85a857f-4d70-4099-b84f-a6b74ea999de/approve/ HTTP/1.1 Authorization: Bearer <access_token> Cbe-User-Org-Id: 123456789 ```

        :param agent_id: (required)
        :type agent_id: UUID
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._approve_agent_agent_agent_id_approve_post_serialize(
            agent_id=agent_id,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "204": None,
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        return response_data.response

    def _approve_agent_agent_agent_id_approve_post_serialize(
        self,
        agent_id,
        cbe_user_org_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if agent_id is not None:
            _path_params["agent_id"] = agent_id
        # process the query parameters
        # process the header parameters
        if cbe_user_org_id is not None:
            _header_params["cbe-user-org-id"] = cbe_user_org_id
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])

        # authentication setting
        _auth_settings: List[str] = ["ZitadelWebAuthorizationBearer", "BearerToken"]

        return self.api_client.param_serialize(
            method="POST",
            resource_path="/agent/{agent_id}/approve/",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def delete_agent_agent_agent_id_delete(
        self,
        agent_id: UUID,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> object:
        """Delete Agent


        :param agent_id: (required)
        :type agent_id: UUID
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._delete_agent_agent_agent_id_delete_serialize(
            agent_id=agent_id,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "object",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def delete_agent_agent_agent_id_delete_with_http_info(
        self,
        agent_id: UUID,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[object]:
        """Delete Agent


        :param agent_id: (required)
        :type agent_id: UUID
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._delete_agent_agent_agent_id_delete_serialize(
            agent_id=agent_id,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "object",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def delete_agent_agent_agent_id_delete_without_preload_content(
        self,
        agent_id: UUID,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete Agent


        :param agent_id: (required)
        :type agent_id: UUID
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._delete_agent_agent_agent_id_delete_serialize(
            agent_id=agent_id,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "object",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        return response_data.response

    def _delete_agent_agent_agent_id_delete_serialize(
        self,
        agent_id,
        cbe_user_org_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if agent_id is not None:
            _path_params["agent_id"] = agent_id
        # process the query parameters
        # process the header parameters
        if cbe_user_org_id is not None:
            _header_params["cbe-user-org-id"] = cbe_user_org_id
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])

        # authentication setting
        _auth_settings: List[str] = ["ZitadelWebAuthorizationBearer", "BearerToken"]

        return self.api_client.param_serialize(
            method="DELETE",
            resource_path="/agent/{agent_id}/",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def get_agent_agent_unregistered_get(
        self,
        page: Optional[Annotated[int, Field(strict=True, ge=0)]] = None,
        per_page: Optional[Annotated[int, Field(le=50, strict=True, ge=1)]] = None,
        order_by: Optional[List[StrictStr]] = None,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PageUnregisteredAgentInfo:
        """Get Agent

        # List unregistered agents  Fetch a paginated list of agents that are connected to the backend but **not yet registered** - i.e. agents awaiting approval. Approve one with `POST /agent/{agent_id}/approve/` to turn it into a registered agent visible in `GET /agent/`.  **Endpoint**: `GET /agent/unregistered/`  **Auth**: requires an authenticated user.  ## Query parameters - `page` (int, default 0): Zero-based page index. - `per_page` (int, default 25, max 50): Page size. - `order_by` (list[str]): Optional sort fields forwarded to the backend.  ## Response `200 OK` with a `Page[UnregisteredAgentInfo]` body: - `page`, `per_page`, `total_items`, `total_pages`: Pagination metadata. - `items`: Array of unregistered agents with fields:   - `id` (uuid): Agent identifier. Pass this to `POST /agent/{agent_id}/approve/`.   - `machine_id` (string): Stable hardware/machine identifier.   - `host_name` (string): Reported host name.   - `os_family` (string, nullable): Operating system family (e.g. `windows`, `linux`).   - `os_details` (string, nullable): Detailed OS description.   - `version` (string, nullable): Agent software version.   - `last_seen` (datetime): Last time the agent contacted the system.  ### Example  ```http GET /agent/unregistered/?page=0&per_page=25 HTTP/1.1 Authorization: Bearer <access_token> ```  ```json {   \"page\": 0,   \"per_page\": 25,   \"total_items\": 1,   \"total_pages\": 1,   \"items\": [     {       \"id\": \"c85a857f-4d70-4099-b84f-a6b74ea999de\",       \"machine_id\": \"S-1-5-21-1004336348\",       \"host_name\": \"WIN-WORKSTATION-02\",       \"domain_name\": \"company.local\",       \"os_family\": \"windows\",       \"os_details\": \"Windows 11 Pro 23H2\",       \"version\": \"1.4.2\",       \"last_seen\": \"2024-05-06T12:00:00Z\"     }   ] } ```

        :param page:
        :type page: int
        :param per_page:
        :type per_page: int
        :param order_by:
        :type order_by: List[str]
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_agent_agent_unregistered_get_serialize(
            page=page,
            per_page=per_page,
            order_by=order_by,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PageUnregisteredAgentInfo",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def get_agent_agent_unregistered_get_with_http_info(
        self,
        page: Optional[Annotated[int, Field(strict=True, ge=0)]] = None,
        per_page: Optional[Annotated[int, Field(le=50, strict=True, ge=1)]] = None,
        order_by: Optional[List[StrictStr]] = None,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PageUnregisteredAgentInfo]:
        """Get Agent

        # List unregistered agents  Fetch a paginated list of agents that are connected to the backend but **not yet registered** - i.e. agents awaiting approval. Approve one with `POST /agent/{agent_id}/approve/` to turn it into a registered agent visible in `GET /agent/`.  **Endpoint**: `GET /agent/unregistered/`  **Auth**: requires an authenticated user.  ## Query parameters - `page` (int, default 0): Zero-based page index. - `per_page` (int, default 25, max 50): Page size. - `order_by` (list[str]): Optional sort fields forwarded to the backend.  ## Response `200 OK` with a `Page[UnregisteredAgentInfo]` body: - `page`, `per_page`, `total_items`, `total_pages`: Pagination metadata. - `items`: Array of unregistered agents with fields:   - `id` (uuid): Agent identifier. Pass this to `POST /agent/{agent_id}/approve/`.   - `machine_id` (string): Stable hardware/machine identifier.   - `host_name` (string): Reported host name.   - `os_family` (string, nullable): Operating system family (e.g. `windows`, `linux`).   - `os_details` (string, nullable): Detailed OS description.   - `version` (string, nullable): Agent software version.   - `last_seen` (datetime): Last time the agent contacted the system.  ### Example  ```http GET /agent/unregistered/?page=0&per_page=25 HTTP/1.1 Authorization: Bearer <access_token> ```  ```json {   \"page\": 0,   \"per_page\": 25,   \"total_items\": 1,   \"total_pages\": 1,   \"items\": [     {       \"id\": \"c85a857f-4d70-4099-b84f-a6b74ea999de\",       \"machine_id\": \"S-1-5-21-1004336348\",       \"host_name\": \"WIN-WORKSTATION-02\",       \"domain_name\": \"company.local\",       \"os_family\": \"windows\",       \"os_details\": \"Windows 11 Pro 23H2\",       \"version\": \"1.4.2\",       \"last_seen\": \"2024-05-06T12:00:00Z\"     }   ] } ```

        :param page:
        :type page: int
        :param per_page:
        :type per_page: int
        :param order_by:
        :type order_by: List[str]
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_agent_agent_unregistered_get_serialize(
            page=page,
            per_page=per_page,
            order_by=order_by,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PageUnregisteredAgentInfo",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def get_agent_agent_unregistered_get_without_preload_content(
        self,
        page: Optional[Annotated[int, Field(strict=True, ge=0)]] = None,
        per_page: Optional[Annotated[int, Field(le=50, strict=True, ge=1)]] = None,
        order_by: Optional[List[StrictStr]] = None,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Agent

        # List unregistered agents  Fetch a paginated list of agents that are connected to the backend but **not yet registered** - i.e. agents awaiting approval. Approve one with `POST /agent/{agent_id}/approve/` to turn it into a registered agent visible in `GET /agent/`.  **Endpoint**: `GET /agent/unregistered/`  **Auth**: requires an authenticated user.  ## Query parameters - `page` (int, default 0): Zero-based page index. - `per_page` (int, default 25, max 50): Page size. - `order_by` (list[str]): Optional sort fields forwarded to the backend.  ## Response `200 OK` with a `Page[UnregisteredAgentInfo]` body: - `page`, `per_page`, `total_items`, `total_pages`: Pagination metadata. - `items`: Array of unregistered agents with fields:   - `id` (uuid): Agent identifier. Pass this to `POST /agent/{agent_id}/approve/`.   - `machine_id` (string): Stable hardware/machine identifier.   - `host_name` (string): Reported host name.   - `os_family` (string, nullable): Operating system family (e.g. `windows`, `linux`).   - `os_details` (string, nullable): Detailed OS description.   - `version` (string, nullable): Agent software version.   - `last_seen` (datetime): Last time the agent contacted the system.  ### Example  ```http GET /agent/unregistered/?page=0&per_page=25 HTTP/1.1 Authorization: Bearer <access_token> ```  ```json {   \"page\": 0,   \"per_page\": 25,   \"total_items\": 1,   \"total_pages\": 1,   \"items\": [     {       \"id\": \"c85a857f-4d70-4099-b84f-a6b74ea999de\",       \"machine_id\": \"S-1-5-21-1004336348\",       \"host_name\": \"WIN-WORKSTATION-02\",       \"domain_name\": \"company.local\",       \"os_family\": \"windows\",       \"os_details\": \"Windows 11 Pro 23H2\",       \"version\": \"1.4.2\",       \"last_seen\": \"2024-05-06T12:00:00Z\"     }   ] } ```

        :param page:
        :type page: int
        :param per_page:
        :type per_page: int
        :param order_by:
        :type order_by: List[str]
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_agent_agent_unregistered_get_serialize(
            page=page,
            per_page=per_page,
            order_by=order_by,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PageUnregisteredAgentInfo",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        return response_data.response

    def _get_agent_agent_unregistered_get_serialize(
        self,
        page,
        per_page,
        order_by,
        cbe_user_org_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            "order_by": "multi",
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if page is not None:
            _query_params.append(("page", page))

        if per_page is not None:
            _query_params.append(("per_page", per_page))

        if order_by is not None:
            _query_params.append(("order_by", order_by))

        # process the header parameters
        if cbe_user_org_id is not None:
            _header_params["cbe-user-org-id"] = cbe_user_org_id
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])

        # authentication setting
        _auth_settings: List[str] = ["ZitadelWebAuthorizationBearer", "BearerToken"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/agent/unregistered/",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def list_agent_agent_get(
        self,
        page: Optional[Annotated[int, Field(strict=True, ge=0)]] = None,
        per_page: Optional[Annotated[int, Field(le=50, strict=True, ge=1)]] = None,
        order_by: Optional[List[StrictStr]] = None,
        id: Optional[List[UUID]] = None,
        machine_id: Optional[List[Optional[Annotated[str, Field(min_length=1, strict=True)]]]] = None,
        custom_name: Optional[List[Annotated[str, Field(min_length=1, strict=True)]]] = None,
        host_name: Optional[List[Annotated[str, Field(min_length=1, strict=True)]]] = None,
        domain_name: Optional[List[Annotated[str, Field(min_length=1, strict=True)]]] = None,
        online: Optional[StrictBool] = None,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PageAgentInfo:
        """List Agent

        # List agents  Fetch a paginated list of all known and **registered** agents.  Most filters accept multiple entries. Values supplied for the same field are combined with an **OR**; values supplied for different fields are combined with an **AND**.  > Unregistered (not-yet-approved) agents are not returned here. Use > `GET /agent/unregistered/` to list agents awaiting approval, then call > `POST /agent/{agent_id}/approve/` to register one.  **Endpoint**: `GET /agent/`  **Auth**: requires an authenticated user.  ## Query parameters - `page` (int, default 0): Zero-based page index. - `per_page` (int, default 25, max 50): Page size. - `order_by` (list[str]): Optional sort fields forwarded to the backend. - `id` (list[uuid]): Filter by one or more agent ids. - `machine_id` (list[string]): Filter by one or more machine ids. - `custom_name` (list[string]): Filter by one or more user-defined names. - `host_name` (list[string]): Filter by one or more host names. - `online` (bool): Filter by current connectivity state.  ## Response `200 OK` with a `Page[AgentInfo]` body: - `page`, `per_page`, `total_items`, `total_pages`: Pagination metadata. - `items`: Array of agents with fields:   - `id` (uuid): Agent identifier.   - `machine_id` (string): Stable hardware/machine identifier.   - `host_name` (string): Reported host name.   - `custom_name` (string, nullable): User-defined display name.   - `version` (string, nullable): Agent software version.   - `online` (bool, nullable): Whether the agent is currently connected.   - `approved_at` (datetime, nullable): When the agent was approved/registered. `null` while unregistered.   - `last_seen` (datetime): Last time the agent contacted the system.   - `lock_reason` (string, nullable): Reason the agent is locked. By default this reflects the keypair credentials expiration. See `POST /agent/{agent_id}/lock/`.   - `locked_at` (datetime, nullable): When the agent was locked. By default this reflects the keypair credentials expiration. A locked agent cannot perform any action until unlocked via `POST /agent/{agent_id}/unlock/`.   - `timestamps`: `created_at`, `updated_at`.  ### Example  ```http GET /agent/?page=0&per_page=25&online=true HTTP/1.1 Authorization: Bearer <access_token> ```  ```json {   \"page\": 0,   \"per_page\": 25,   \"total_items\": 1,   \"total_pages\": 1,   \"items\": [     {       \"id\": \"e33602da-cb5f-4b5f-9c49-6307b32cfac7\",       \"machine_id\": \"S-1-5-21-1004336348\",       \"host_name\": \"WIN-WORKSTATION-01\",       \"custom_name\": \"Reception desk\",       \"version\": \"1.4.2\",       \"online\": true,       \"approved_at\": \"2024-05-01T09:12:33Z\",       \"last_seen\": \"2024-05-06T12:00:00Z\",       \"lock_reason\": \"key_exp\",       \"locked_at\": \"2024-06-02T12:00:00Z\",       \"timestamps\": {         \"created_at\": \"2024-05-01T09:12:33Z\",         \"updated_at\": \"2024-05-06T12:00:00Z\"       }     }   ] } ```

        :param page:
        :type page: int
        :param per_page:
        :type per_page: int
        :param order_by:
        :type order_by: List[str]
        :param id:
        :type id: List[UUID]
        :param machine_id:
        :type machine_id: List[Optional[str]]
        :param custom_name:
        :type custom_name: List[str]
        :param host_name:
        :type host_name: List[str]
        :param domain_name:
        :type domain_name: List[str]
        :param online:
        :type online: bool
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._list_agent_agent_get_serialize(
            page=page,
            per_page=per_page,
            order_by=order_by,
            id=id,
            machine_id=machine_id,
            custom_name=custom_name,
            host_name=host_name,
            domain_name=domain_name,
            online=online,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PageAgentInfo",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def list_agent_agent_get_with_http_info(
        self,
        page: Optional[Annotated[int, Field(strict=True, ge=0)]] = None,
        per_page: Optional[Annotated[int, Field(le=50, strict=True, ge=1)]] = None,
        order_by: Optional[List[StrictStr]] = None,
        id: Optional[List[UUID]] = None,
        machine_id: Optional[List[Optional[Annotated[str, Field(min_length=1, strict=True)]]]] = None,
        custom_name: Optional[List[Annotated[str, Field(min_length=1, strict=True)]]] = None,
        host_name: Optional[List[Annotated[str, Field(min_length=1, strict=True)]]] = None,
        domain_name: Optional[List[Annotated[str, Field(min_length=1, strict=True)]]] = None,
        online: Optional[StrictBool] = None,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PageAgentInfo]:
        """List Agent

        # List agents  Fetch a paginated list of all known and **registered** agents.  Most filters accept multiple entries. Values supplied for the same field are combined with an **OR**; values supplied for different fields are combined with an **AND**.  > Unregistered (not-yet-approved) agents are not returned here. Use > `GET /agent/unregistered/` to list agents awaiting approval, then call > `POST /agent/{agent_id}/approve/` to register one.  **Endpoint**: `GET /agent/`  **Auth**: requires an authenticated user.  ## Query parameters - `page` (int, default 0): Zero-based page index. - `per_page` (int, default 25, max 50): Page size. - `order_by` (list[str]): Optional sort fields forwarded to the backend. - `id` (list[uuid]): Filter by one or more agent ids. - `machine_id` (list[string]): Filter by one or more machine ids. - `custom_name` (list[string]): Filter by one or more user-defined names. - `host_name` (list[string]): Filter by one or more host names. - `online` (bool): Filter by current connectivity state.  ## Response `200 OK` with a `Page[AgentInfo]` body: - `page`, `per_page`, `total_items`, `total_pages`: Pagination metadata. - `items`: Array of agents with fields:   - `id` (uuid): Agent identifier.   - `machine_id` (string): Stable hardware/machine identifier.   - `host_name` (string): Reported host name.   - `custom_name` (string, nullable): User-defined display name.   - `version` (string, nullable): Agent software version.   - `online` (bool, nullable): Whether the agent is currently connected.   - `approved_at` (datetime, nullable): When the agent was approved/registered. `null` while unregistered.   - `last_seen` (datetime): Last time the agent contacted the system.   - `lock_reason` (string, nullable): Reason the agent is locked. By default this reflects the keypair credentials expiration. See `POST /agent/{agent_id}/lock/`.   - `locked_at` (datetime, nullable): When the agent was locked. By default this reflects the keypair credentials expiration. A locked agent cannot perform any action until unlocked via `POST /agent/{agent_id}/unlock/`.   - `timestamps`: `created_at`, `updated_at`.  ### Example  ```http GET /agent/?page=0&per_page=25&online=true HTTP/1.1 Authorization: Bearer <access_token> ```  ```json {   \"page\": 0,   \"per_page\": 25,   \"total_items\": 1,   \"total_pages\": 1,   \"items\": [     {       \"id\": \"e33602da-cb5f-4b5f-9c49-6307b32cfac7\",       \"machine_id\": \"S-1-5-21-1004336348\",       \"host_name\": \"WIN-WORKSTATION-01\",       \"custom_name\": \"Reception desk\",       \"version\": \"1.4.2\",       \"online\": true,       \"approved_at\": \"2024-05-01T09:12:33Z\",       \"last_seen\": \"2024-05-06T12:00:00Z\",       \"lock_reason\": \"key_exp\",       \"locked_at\": \"2024-06-02T12:00:00Z\",       \"timestamps\": {         \"created_at\": \"2024-05-01T09:12:33Z\",         \"updated_at\": \"2024-05-06T12:00:00Z\"       }     }   ] } ```

        :param page:
        :type page: int
        :param per_page:
        :type per_page: int
        :param order_by:
        :type order_by: List[str]
        :param id:
        :type id: List[UUID]
        :param machine_id:
        :type machine_id: List[Optional[str]]
        :param custom_name:
        :type custom_name: List[str]
        :param host_name:
        :type host_name: List[str]
        :param domain_name:
        :type domain_name: List[str]
        :param online:
        :type online: bool
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._list_agent_agent_get_serialize(
            page=page,
            per_page=per_page,
            order_by=order_by,
            id=id,
            machine_id=machine_id,
            custom_name=custom_name,
            host_name=host_name,
            domain_name=domain_name,
            online=online,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PageAgentInfo",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def list_agent_agent_get_without_preload_content(
        self,
        page: Optional[Annotated[int, Field(strict=True, ge=0)]] = None,
        per_page: Optional[Annotated[int, Field(le=50, strict=True, ge=1)]] = None,
        order_by: Optional[List[StrictStr]] = None,
        id: Optional[List[UUID]] = None,
        machine_id: Optional[List[Optional[Annotated[str, Field(min_length=1, strict=True)]]]] = None,
        custom_name: Optional[List[Annotated[str, Field(min_length=1, strict=True)]]] = None,
        host_name: Optional[List[Annotated[str, Field(min_length=1, strict=True)]]] = None,
        domain_name: Optional[List[Annotated[str, Field(min_length=1, strict=True)]]] = None,
        online: Optional[StrictBool] = None,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List Agent

        # List agents  Fetch a paginated list of all known and **registered** agents.  Most filters accept multiple entries. Values supplied for the same field are combined with an **OR**; values supplied for different fields are combined with an **AND**.  > Unregistered (not-yet-approved) agents are not returned here. Use > `GET /agent/unregistered/` to list agents awaiting approval, then call > `POST /agent/{agent_id}/approve/` to register one.  **Endpoint**: `GET /agent/`  **Auth**: requires an authenticated user.  ## Query parameters - `page` (int, default 0): Zero-based page index. - `per_page` (int, default 25, max 50): Page size. - `order_by` (list[str]): Optional sort fields forwarded to the backend. - `id` (list[uuid]): Filter by one or more agent ids. - `machine_id` (list[string]): Filter by one or more machine ids. - `custom_name` (list[string]): Filter by one or more user-defined names. - `host_name` (list[string]): Filter by one or more host names. - `online` (bool): Filter by current connectivity state.  ## Response `200 OK` with a `Page[AgentInfo]` body: - `page`, `per_page`, `total_items`, `total_pages`: Pagination metadata. - `items`: Array of agents with fields:   - `id` (uuid): Agent identifier.   - `machine_id` (string): Stable hardware/machine identifier.   - `host_name` (string): Reported host name.   - `custom_name` (string, nullable): User-defined display name.   - `version` (string, nullable): Agent software version.   - `online` (bool, nullable): Whether the agent is currently connected.   - `approved_at` (datetime, nullable): When the agent was approved/registered. `null` while unregistered.   - `last_seen` (datetime): Last time the agent contacted the system.   - `lock_reason` (string, nullable): Reason the agent is locked. By default this reflects the keypair credentials expiration. See `POST /agent/{agent_id}/lock/`.   - `locked_at` (datetime, nullable): When the agent was locked. By default this reflects the keypair credentials expiration. A locked agent cannot perform any action until unlocked via `POST /agent/{agent_id}/unlock/`.   - `timestamps`: `created_at`, `updated_at`.  ### Example  ```http GET /agent/?page=0&per_page=25&online=true HTTP/1.1 Authorization: Bearer <access_token> ```  ```json {   \"page\": 0,   \"per_page\": 25,   \"total_items\": 1,   \"total_pages\": 1,   \"items\": [     {       \"id\": \"e33602da-cb5f-4b5f-9c49-6307b32cfac7\",       \"machine_id\": \"S-1-5-21-1004336348\",       \"host_name\": \"WIN-WORKSTATION-01\",       \"custom_name\": \"Reception desk\",       \"version\": \"1.4.2\",       \"online\": true,       \"approved_at\": \"2024-05-01T09:12:33Z\",       \"last_seen\": \"2024-05-06T12:00:00Z\",       \"lock_reason\": \"key_exp\",       \"locked_at\": \"2024-06-02T12:00:00Z\",       \"timestamps\": {         \"created_at\": \"2024-05-01T09:12:33Z\",         \"updated_at\": \"2024-05-06T12:00:00Z\"       }     }   ] } ```

        :param page:
        :type page: int
        :param per_page:
        :type per_page: int
        :param order_by:
        :type order_by: List[str]
        :param id:
        :type id: List[UUID]
        :param machine_id:
        :type machine_id: List[Optional[str]]
        :param custom_name:
        :type custom_name: List[str]
        :param host_name:
        :type host_name: List[str]
        :param domain_name:
        :type domain_name: List[str]
        :param online:
        :type online: bool
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._list_agent_agent_get_serialize(
            page=page,
            per_page=per_page,
            order_by=order_by,
            id=id,
            machine_id=machine_id,
            custom_name=custom_name,
            host_name=host_name,
            domain_name=domain_name,
            online=online,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PageAgentInfo",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        return response_data.response

    def _list_agent_agent_get_serialize(
        self,
        page,
        per_page,
        order_by,
        id,
        machine_id,
        custom_name,
        host_name,
        domain_name,
        online,
        cbe_user_org_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            "order_by": "multi",
            "id": "multi",
            "machine_id": "multi",
            "custom_name": "multi",
            "host_name": "multi",
            "domain_name": "multi",
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if page is not None:
            _query_params.append(("page", page))

        if per_page is not None:
            _query_params.append(("per_page", per_page))

        if order_by is not None:
            _query_params.append(("order_by", order_by))

        if id is not None:
            _query_params.append(("id", id))

        if machine_id is not None:
            _query_params.append(("machine_id", machine_id))

        if custom_name is not None:
            _query_params.append(("custom_name", custom_name))

        if host_name is not None:
            _query_params.append(("host_name", host_name))

        if domain_name is not None:
            _query_params.append(("domain_name", domain_name))

        if online is not None:
            _query_params.append(("online", online))

        # process the header parameters
        if cbe_user_org_id is not None:
            _header_params["cbe-user-org-id"] = cbe_user_org_id
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])

        # authentication setting
        _auth_settings: List[str] = ["ZitadelWebAuthorizationBearer", "BearerToken"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/agent/",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def lock_agent_agent_agent_id_lock_post(
        self,
        agent_id: UUID,
        agent_lock: AgentLock,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Lock Agent

        # Lock agent  \"Block\" an agent in the system. A locked agent is forbidden from performing any action, but its data is preserved and the agent is **not** deleted; it can be re-enabled later via `POST /agent/{agent_id}/unlock/`.  Every agent carries `locked_at` and `lock_reason` properties. By default these reflect the keypair credentials expiration: the value is updated automatically when the agent detects its key is about to expire. An agent that stays offline for too long is also locked automatically, and must then be unlocked manually.  This endpoint locks the agent explicitly with a custom reason.  **Endpoint**: `POST /agent/{agent_id}/lock/`  **Auth**: requires an authenticated user.  ## Path parameter - `agent_id` (uuid, required): Identifier of the agent to lock.  ## Request body (AgentLock) - `lock_reason` (string, required): Non-empty human-readable reason for locking the agent. Stored on the agent's `lock_reason` property.  ## Response - `204 No Content`: The agent was locked.  ### Example  ```http POST /agent/e33602da-cb5f-4b5f-9c49-6307b32cfac7/lock/ HTTP/1.1 Authorization: Bearer <access_token> Content-Type: application/json  {   \"lock_reason\": \"Decommissioned workstation\" } ```

        :param agent_id: (required)
        :type agent_id: UUID
        :param agent_lock: (required)
        :type agent_lock: AgentLock
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._lock_agent_agent_agent_id_lock_post_serialize(
            agent_id=agent_id,
            agent_lock=agent_lock,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "204": None,
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def lock_agent_agent_agent_id_lock_post_with_http_info(
        self,
        agent_id: UUID,
        agent_lock: AgentLock,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Lock Agent

        # Lock agent  \"Block\" an agent in the system. A locked agent is forbidden from performing any action, but its data is preserved and the agent is **not** deleted; it can be re-enabled later via `POST /agent/{agent_id}/unlock/`.  Every agent carries `locked_at` and `lock_reason` properties. By default these reflect the keypair credentials expiration: the value is updated automatically when the agent detects its key is about to expire. An agent that stays offline for too long is also locked automatically, and must then be unlocked manually.  This endpoint locks the agent explicitly with a custom reason.  **Endpoint**: `POST /agent/{agent_id}/lock/`  **Auth**: requires an authenticated user.  ## Path parameter - `agent_id` (uuid, required): Identifier of the agent to lock.  ## Request body (AgentLock) - `lock_reason` (string, required): Non-empty human-readable reason for locking the agent. Stored on the agent's `lock_reason` property.  ## Response - `204 No Content`: The agent was locked.  ### Example  ```http POST /agent/e33602da-cb5f-4b5f-9c49-6307b32cfac7/lock/ HTTP/1.1 Authorization: Bearer <access_token> Content-Type: application/json  {   \"lock_reason\": \"Decommissioned workstation\" } ```

        :param agent_id: (required)
        :type agent_id: UUID
        :param agent_lock: (required)
        :type agent_lock: AgentLock
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._lock_agent_agent_agent_id_lock_post_serialize(
            agent_id=agent_id,
            agent_lock=agent_lock,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "204": None,
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def lock_agent_agent_agent_id_lock_post_without_preload_content(
        self,
        agent_id: UUID,
        agent_lock: AgentLock,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Lock Agent

        # Lock agent  \"Block\" an agent in the system. A locked agent is forbidden from performing any action, but its data is preserved and the agent is **not** deleted; it can be re-enabled later via `POST /agent/{agent_id}/unlock/`.  Every agent carries `locked_at` and `lock_reason` properties. By default these reflect the keypair credentials expiration: the value is updated automatically when the agent detects its key is about to expire. An agent that stays offline for too long is also locked automatically, and must then be unlocked manually.  This endpoint locks the agent explicitly with a custom reason.  **Endpoint**: `POST /agent/{agent_id}/lock/`  **Auth**: requires an authenticated user.  ## Path parameter - `agent_id` (uuid, required): Identifier of the agent to lock.  ## Request body (AgentLock) - `lock_reason` (string, required): Non-empty human-readable reason for locking the agent. Stored on the agent's `lock_reason` property.  ## Response - `204 No Content`: The agent was locked.  ### Example  ```http POST /agent/e33602da-cb5f-4b5f-9c49-6307b32cfac7/lock/ HTTP/1.1 Authorization: Bearer <access_token> Content-Type: application/json  {   \"lock_reason\": \"Decommissioned workstation\" } ```

        :param agent_id: (required)
        :type agent_id: UUID
        :param agent_lock: (required)
        :type agent_lock: AgentLock
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._lock_agent_agent_agent_id_lock_post_serialize(
            agent_id=agent_id,
            agent_lock=agent_lock,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "204": None,
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        return response_data.response

    def _lock_agent_agent_agent_id_lock_post_serialize(
        self,
        agent_id,
        agent_lock,
        cbe_user_org_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if agent_id is not None:
            _path_params["agent_id"] = agent_id
        # process the query parameters
        # process the header parameters
        if cbe_user_org_id is not None:
            _header_params["cbe-user-org-id"] = cbe_user_org_id
        # process the form parameters
        # process the body parameter
        if agent_lock is not None:
            _body_params = agent_lock

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params["Content-Type"] = _content_type
        else:
            _default_content_type = self.api_client.select_header_content_type(["application/json"])
            if _default_content_type is not None:
                _header_params["Content-Type"] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = ["ZitadelWebAuthorizationBearer", "BearerToken"]

        return self.api_client.param_serialize(
            method="POST",
            resource_path="/agent/{agent_id}/lock/",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def unlock_agent_agent_agent_id_unlock_post(
        self,
        agent_id: UUID,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Unlock Agent

        # Unlock agent  Unlock an agent that has previously been locked, allowing it back into the system so it can perform actions again. This clears the lock set either explicitly via `POST /agent/{agent_id}/lock/` or automatically (for example when the agent has been offline for too long, or its keypair credentials were about to expire).  **Endpoint**: `POST /agent/{agent_id}/unlock/`  **Auth**: requires an authenticated user.  ## Path parameter - `agent_id` (uuid, required): Identifier of the locked agent to unlock.  ## Response - `204 No Content`: The agent was unlocked.  ### Example  ```http POST /agent/e33602da-cb5f-4b5f-9c49-6307b32cfac7/unlock/ HTTP/1.1 Authorization: Bearer <access_token> ```

        :param agent_id: (required)
        :type agent_id: UUID
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._unlock_agent_agent_agent_id_unlock_post_serialize(
            agent_id=agent_id,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "204": None,
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def unlock_agent_agent_agent_id_unlock_post_with_http_info(
        self,
        agent_id: UUID,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Unlock Agent

        # Unlock agent  Unlock an agent that has previously been locked, allowing it back into the system so it can perform actions again. This clears the lock set either explicitly via `POST /agent/{agent_id}/lock/` or automatically (for example when the agent has been offline for too long, or its keypair credentials were about to expire).  **Endpoint**: `POST /agent/{agent_id}/unlock/`  **Auth**: requires an authenticated user.  ## Path parameter - `agent_id` (uuid, required): Identifier of the locked agent to unlock.  ## Response - `204 No Content`: The agent was unlocked.  ### Example  ```http POST /agent/e33602da-cb5f-4b5f-9c49-6307b32cfac7/unlock/ HTTP/1.1 Authorization: Bearer <access_token> ```

        :param agent_id: (required)
        :type agent_id: UUID
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._unlock_agent_agent_agent_id_unlock_post_serialize(
            agent_id=agent_id,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "204": None,
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def unlock_agent_agent_agent_id_unlock_post_without_preload_content(
        self,
        agent_id: UUID,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Unlock Agent

        # Unlock agent  Unlock an agent that has previously been locked, allowing it back into the system so it can perform actions again. This clears the lock set either explicitly via `POST /agent/{agent_id}/lock/` or automatically (for example when the agent has been offline for too long, or its keypair credentials were about to expire).  **Endpoint**: `POST /agent/{agent_id}/unlock/`  **Auth**: requires an authenticated user.  ## Path parameter - `agent_id` (uuid, required): Identifier of the locked agent to unlock.  ## Response - `204 No Content`: The agent was unlocked.  ### Example  ```http POST /agent/e33602da-cb5f-4b5f-9c49-6307b32cfac7/unlock/ HTTP/1.1 Authorization: Bearer <access_token> ```

        :param agent_id: (required)
        :type agent_id: UUID
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._unlock_agent_agent_agent_id_unlock_post_serialize(
            agent_id=agent_id,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "204": None,
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        return response_data.response

    def _unlock_agent_agent_agent_id_unlock_post_serialize(
        self,
        agent_id,
        cbe_user_org_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if agent_id is not None:
            _path_params["agent_id"] = agent_id
        # process the query parameters
        # process the header parameters
        if cbe_user_org_id is not None:
            _header_params["cbe-user-org-id"] = cbe_user_org_id
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])

        # authentication setting
        _auth_settings: List[str] = ["ZitadelWebAuthorizationBearer", "BearerToken"]

        return self.api_client.param_serialize(
            method="POST",
            resource_path="/agent/{agent_id}/unlock/",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def update_agent_agent_agent_id_put(
        self,
        agent_id: UUID,
        agent_update: AgentUpdate,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> object:
        """Update Agent


        :param agent_id: (required)
        :type agent_id: UUID
        :param agent_update: (required)
        :type agent_update: AgentUpdate
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._update_agent_agent_agent_id_put_serialize(
            agent_id=agent_id,
            agent_update=agent_update,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "object",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def update_agent_agent_agent_id_put_with_http_info(
        self,
        agent_id: UUID,
        agent_update: AgentUpdate,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[object]:
        """Update Agent


        :param agent_id: (required)
        :type agent_id: UUID
        :param agent_update: (required)
        :type agent_update: AgentUpdate
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._update_agent_agent_agent_id_put_serialize(
            agent_id=agent_id,
            agent_update=agent_update,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "object",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def update_agent_agent_agent_id_put_without_preload_content(
        self,
        agent_id: UUID,
        agent_update: AgentUpdate,
        cbe_user_org_id: Annotated[
            Optional[Annotated[str, Field(strict=True, max_length=20)]],
            Field(
                description=" Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/` "
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update Agent


        :param agent_id: (required)
        :type agent_id: UUID
        :param agent_update: (required)
        :type agent_update: AgentUpdate
        :param cbe_user_org_id:  Organization ID to request against. Can be empty (uses the user's org), a specific ID, or an asterisk (*) in which case the returned data are sourced from all orgs you can access.  See `/identity/organization/`
        :type cbe_user_org_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._update_agent_agent_agent_id_put_serialize(
            agent_id=agent_id,
            agent_update=agent_update,
            cbe_user_org_id=cbe_user_org_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "object",
            "422": "HTTPValidationError",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)
        return response_data.response

    def _update_agent_agent_agent_id_put_serialize(
        self,
        agent_id,
        agent_update,
        cbe_user_org_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if agent_id is not None:
            _path_params["agent_id"] = agent_id
        # process the query parameters
        # process the header parameters
        if cbe_user_org_id is not None:
            _header_params["cbe-user-org-id"] = cbe_user_org_id
        # process the form parameters
        # process the body parameter
        if agent_update is not None:
            _body_params = agent_update

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params["Content-Type"] = _content_type
        else:
            _default_content_type = self.api_client.select_header_content_type(["application/json"])
            if _default_content_type is not None:
                _header_params["Content-Type"] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = ["ZitadelWebAuthorizationBearer", "BearerToken"]

        return self.api_client.param_serialize(
            method="PUT",
            resource_path="/agent/{agent_id}/",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )



# coding: utf-8

# flake8: noqa

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

__version__ = "0.42.0"

# Define package exports
__all__ = [
    "AgentsApi",
    "CmdbApi",
    "IdentityApi",
    "NotificationApi",
    "PlansBackupApi",
    "PlansRestoreApi",
    "PlansScheduleApi",
    "StorageAccountApi",
    "StorageDestinationApi",
    "StorageRepositoryApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AdditionalAgentFilter",
    "Addr",
    "AgentInfo",
    "AgentLock",
    "AgentNotificationFilter",
    "AgentUpdate",
    "ApiKey",
    "BackupError",
    "BackupFatalError",
    "BackupInfo",
    "BackupNotificationFilterInput",
    "BackupNotificationFilterOutput",
    "BackupPlanError",
    "BackupPlanRun",
    "BackupStatus",
    "BackupSummary",
    "BackupVerboseStatus",
    "Channel",
    "ChannelCreate",
    "ChannelType",
    "CommonNotifyFilter",
    "CoresGroup",
    "CreateScheduling",
    "CronCalendar",
    "Dns",
    "DriveType",
    "ExcludeLargerThan",
    "ExcludeLargerThan1",
    "FileBackupPlan",
    "FileBackupPlanCreate",
    "FileBackupPlanUpdate",
    "FileRestorePlan",
    "FileRestorePlanCreate",
    "FileRestorePlanUpdate",
    "Filesystem",
    "GenerateKeyRequest",
    "GeneratedApiKey",
    "GlobalResticOptions",
    "HTTPValidationError",
    "HistoricalMachine",
    "IPVersion",
    "Iface",
    "ImageBackupPlan",
    "ImageBackupPlanCreate",
    "ImageBackupPlanExtension",
    "ImageBackupPlanUpdate",
    "ImageRestorePlan",
    "ImageRestorePlanCreate",
    "ImageRestorePlanExtension",
    "ImageRestorePlanUpdate",
    "LocationInner",
    "Machine",
    "MaintenanceStatus",
    "MaintenanceType",
    "MassStorage",
    "Memory",
    "NotificationFilterInput",
    "NotificationFilterOutput",
    "Ntp",
    "NtpSynchronized",
    "Organization",
    "Os",
    "PageAgentInfo",
    "PageApiKey",
    "PageBackupPlanError",
    "PageBackupPlanRun",
    "PageChannel",
    "PageFileBackupPlan",
    "PageFileRestorePlan",
    "PageHistoricalMachine",
    "PageImageBackupPlan",
    "PageImageRestorePlan",
    "PageMachine",
    "PageOrganization",
    "PageRepository",
    "PageRepositoryChecks",
    "PageRepositoryPrunes",
    "PageRepositoryStats",
    "PageRestorePlanError",
    "PageRestorePlanRun",
    "PageRouter",
    "PageScheduling",
    "PageStorageAccount",
    "PageStorageDestination",
    "PageTemplate",
    "PageUnregisteredAgentInfo",
    "Partition",
    "PhyCpu",
    "PhyDrive",
    "PlanStatus",
    "PlanType",
    "PrePostRunScript",
    "PydGenericMessage",
    "PydMessageType",
    "Repository",
    "RepositoryChecks",
    "RepositoryCreate",
    "RepositoryMaintenance",
    "RepositoryMaintenanceCreateUpdate",
    "RepositoryPrunes",
    "RepositoryStats",
    "RepositoryStatusEnum",
    "RepositoryUpdate",
    "ResticBackupInput",
    "ResticBackupOutput",
    "ResticRestore",
    "ResticStatsModeEnum",
    "ResticVersionEnum",
    "RestorationError",
    "RestorationInfo",
    "RestorationStatus",
    "RestorationSummary",
    "RestoreNotificationFilterInput",
    "RestoreNotificationFilterOutput",
    "RestorePlanError",
    "RestorePlanRun",
    "RestoreSummary",
    "RestoreVerboseStatus",
    "RetentionSettings",
    "Router",
    "RouterCreate",
    "RouterUpdate",
    "S3Provider",
    "S3SignatureVersionEnum",
    "S3StorageAccountConfig",
    "Scheduling",
    "SchedulingLinkedPlans",
    "Snapshot",
    "StorageAccount",
    "StorageAccountCreate",
    "StorageAccountUpdate",
    "StorageDestination",
    "StorageDestinationConfig",
    "StorageDestinationCreate",
    "StorageDestinationUpdate",
    "StorageFormat",
    "StorageNotificationFilter",
    "Template",
    "TemplateCreate",
    "TimeStamps",
    "UnregisteredAgentInfo",
    "UpdateScheduling",
    "ValidationError",
    "ZitadelApiKeyType",
]

# import apis into sdk package
from cybee_sdk.api.api.agents_api import AgentsApi as AgentsApi
from cybee_sdk.api.api.cmdb_api import CmdbApi as CmdbApi
from cybee_sdk.api.api.identity_api import IdentityApi as IdentityApi
from cybee_sdk.api.api.notification_api import NotificationApi as NotificationApi
from cybee_sdk.api.api.plans_backup_api import PlansBackupApi as PlansBackupApi
from cybee_sdk.api.api.plans_restore_api import PlansRestoreApi as PlansRestoreApi
from cybee_sdk.api.api.plans_schedule_api import PlansScheduleApi as PlansScheduleApi
from cybee_sdk.api.api.storage_account_api import StorageAccountApi as StorageAccountApi
from cybee_sdk.api.api.storage_destination_api import StorageDestinationApi as StorageDestinationApi
from cybee_sdk.api.api.storage_repository_api import StorageRepositoryApi as StorageRepositoryApi

# import ApiClient
from cybee_sdk.api.api_response import ApiResponse as ApiResponse
from cybee_sdk.api.api_client import ApiClient as ApiClient
from cybee_sdk.api.configuration import Configuration as Configuration
from cybee_sdk.api.exceptions import OpenApiException as OpenApiException
from cybee_sdk.api.exceptions import ApiTypeError as ApiTypeError
from cybee_sdk.api.exceptions import ApiValueError as ApiValueError
from cybee_sdk.api.exceptions import ApiKeyError as ApiKeyError
from cybee_sdk.api.exceptions import ApiAttributeError as ApiAttributeError
from cybee_sdk.api.exceptions import ApiException as ApiException

# import models into sdk package
from cybee_sdk.api.models.additional_agent_filter import AdditionalAgentFilter as AdditionalAgentFilter
from cybee_sdk.api.models.addr import Addr as Addr
from cybee_sdk.api.models.agent_info import AgentInfo as AgentInfo
from cybee_sdk.api.models.agent_lock import AgentLock as AgentLock
from cybee_sdk.api.models.agent_notification_filter import AgentNotificationFilter as AgentNotificationFilter
from cybee_sdk.api.models.agent_update import AgentUpdate as AgentUpdate
from cybee_sdk.api.models.api_key import ApiKey as ApiKey
from cybee_sdk.api.models.backup_error import BackupError as BackupError
from cybee_sdk.api.models.backup_fatal_error import BackupFatalError as BackupFatalError
from cybee_sdk.api.models.backup_info import BackupInfo as BackupInfo
from cybee_sdk.api.models.backup_notification_filter_input import (
    BackupNotificationFilterInput as BackupNotificationFilterInput,
)
from cybee_sdk.api.models.backup_notification_filter_output import (
    BackupNotificationFilterOutput as BackupNotificationFilterOutput,
)
from cybee_sdk.api.models.backup_plan_error import BackupPlanError as BackupPlanError
from cybee_sdk.api.models.backup_plan_run import BackupPlanRun as BackupPlanRun
from cybee_sdk.api.models.backup_status import BackupStatus as BackupStatus
from cybee_sdk.api.models.backup_summary import BackupSummary as BackupSummary
from cybee_sdk.api.models.backup_verbose_status import BackupVerboseStatus as BackupVerboseStatus
from cybee_sdk.api.models.channel import Channel as Channel
from cybee_sdk.api.models.channel_create import ChannelCreate as ChannelCreate
from cybee_sdk.api.models.channel_type import ChannelType as ChannelType
from cybee_sdk.api.models.common_notify_filter import CommonNotifyFilter as CommonNotifyFilter
from cybee_sdk.api.models.cores_group import CoresGroup as CoresGroup
from cybee_sdk.api.models.create_scheduling import CreateScheduling as CreateScheduling
from cybee_sdk.api.models.cron_calendar import CronCalendar as CronCalendar
from cybee_sdk.api.models.dns import Dns as Dns
from cybee_sdk.api.models.drive_type import DriveType as DriveType
from cybee_sdk.api.models.exclude_larger_than import ExcludeLargerThan as ExcludeLargerThan
from cybee_sdk.api.models.exclude_larger_than1 import ExcludeLargerThan1 as ExcludeLargerThan1
from cybee_sdk.api.models.file_backup_plan import FileBackupPlan as FileBackupPlan
from cybee_sdk.api.models.file_backup_plan_create import FileBackupPlanCreate as FileBackupPlanCreate
from cybee_sdk.api.models.file_backup_plan_update import FileBackupPlanUpdate as FileBackupPlanUpdate
from cybee_sdk.api.models.file_restore_plan import FileRestorePlan as FileRestorePlan
from cybee_sdk.api.models.file_restore_plan_create import FileRestorePlanCreate as FileRestorePlanCreate
from cybee_sdk.api.models.file_restore_plan_update import FileRestorePlanUpdate as FileRestorePlanUpdate
from cybee_sdk.api.models.filesystem import Filesystem as Filesystem
from cybee_sdk.api.models.generate_key_request import GenerateKeyRequest as GenerateKeyRequest
from cybee_sdk.api.models.generated_api_key import GeneratedApiKey as GeneratedApiKey
from cybee_sdk.api.models.global_restic_options import GlobalResticOptions as GlobalResticOptions
from cybee_sdk.api.models.http_validation_error import HTTPValidationError as HTTPValidationError
from cybee_sdk.api.models.historical_machine import HistoricalMachine as HistoricalMachine
from cybee_sdk.api.models.ip_version import IPVersion as IPVersion
from cybee_sdk.api.models.iface import Iface as Iface
from cybee_sdk.api.models.image_backup_plan import ImageBackupPlan as ImageBackupPlan
from cybee_sdk.api.models.image_backup_plan_create import ImageBackupPlanCreate as ImageBackupPlanCreate
from cybee_sdk.api.models.image_backup_plan_extension import ImageBackupPlanExtension as ImageBackupPlanExtension
from cybee_sdk.api.models.image_backup_plan_update import ImageBackupPlanUpdate as ImageBackupPlanUpdate
from cybee_sdk.api.models.image_restore_plan import ImageRestorePlan as ImageRestorePlan
from cybee_sdk.api.models.image_restore_plan_create import ImageRestorePlanCreate as ImageRestorePlanCreate
from cybee_sdk.api.models.image_restore_plan_extension import ImageRestorePlanExtension as ImageRestorePlanExtension
from cybee_sdk.api.models.image_restore_plan_update import ImageRestorePlanUpdate as ImageRestorePlanUpdate
from cybee_sdk.api.models.location_inner import LocationInner as LocationInner
from cybee_sdk.api.models.machine import Machine as Machine
from cybee_sdk.api.models.maintenance_status import MaintenanceStatus as MaintenanceStatus
from cybee_sdk.api.models.maintenance_type import MaintenanceType as MaintenanceType
from cybee_sdk.api.models.mass_storage import MassStorage as MassStorage
from cybee_sdk.api.models.memory import Memory as Memory
from cybee_sdk.api.models.notification_filter_input import NotificationFilterInput as NotificationFilterInput
from cybee_sdk.api.models.notification_filter_output import NotificationFilterOutput as NotificationFilterOutput
from cybee_sdk.api.models.ntp import Ntp as Ntp
from cybee_sdk.api.models.ntp_synchronized import NtpSynchronized as NtpSynchronized
from cybee_sdk.api.models.organization import Organization as Organization
from cybee_sdk.api.models.os import Os as Os
from cybee_sdk.api.models.page_agent_info import PageAgentInfo as PageAgentInfo
from cybee_sdk.api.models.page_api_key import PageApiKey as PageApiKey
from cybee_sdk.api.models.page_backup_plan_error import PageBackupPlanError as PageBackupPlanError
from cybee_sdk.api.models.page_backup_plan_run import PageBackupPlanRun as PageBackupPlanRun
from cybee_sdk.api.models.page_channel import PageChannel as PageChannel
from cybee_sdk.api.models.page_file_backup_plan import PageFileBackupPlan as PageFileBackupPlan
from cybee_sdk.api.models.page_file_restore_plan import PageFileRestorePlan as PageFileRestorePlan
from cybee_sdk.api.models.page_historical_machine import PageHistoricalMachine as PageHistoricalMachine
from cybee_sdk.api.models.page_image_backup_plan import PageImageBackupPlan as PageImageBackupPlan
from cybee_sdk.api.models.page_image_restore_plan import PageImageRestorePlan as PageImageRestorePlan
from cybee_sdk.api.models.page_machine import PageMachine as PageMachine
from cybee_sdk.api.models.page_organization import PageOrganization as PageOrganization
from cybee_sdk.api.models.page_repository import PageRepository as PageRepository
from cybee_sdk.api.models.page_repository_checks import PageRepositoryChecks as PageRepositoryChecks
from cybee_sdk.api.models.page_repository_prunes import PageRepositoryPrunes as PageRepositoryPrunes
from cybee_sdk.api.models.page_repository_stats import PageRepositoryStats as PageRepositoryStats
from cybee_sdk.api.models.page_restore_plan_error import PageRestorePlanError as PageRestorePlanError
from cybee_sdk.api.models.page_restore_plan_run import PageRestorePlanRun as PageRestorePlanRun
from cybee_sdk.api.models.page_router import PageRouter as PageRouter
from cybee_sdk.api.models.page_scheduling import PageScheduling as PageScheduling
from cybee_sdk.api.models.page_storage_account import PageStorageAccount as PageStorageAccount
from cybee_sdk.api.models.page_storage_destination import PageStorageDestination as PageStorageDestination
from cybee_sdk.api.models.page_template import PageTemplate as PageTemplate
from cybee_sdk.api.models.page_unregistered_agent_info import PageUnregisteredAgentInfo as PageUnregisteredAgentInfo
from cybee_sdk.api.models.partition import Partition as Partition
from cybee_sdk.api.models.phy_cpu import PhyCpu as PhyCpu
from cybee_sdk.api.models.phy_drive import PhyDrive as PhyDrive
from cybee_sdk.api.models.plan_status import PlanStatus as PlanStatus
from cybee_sdk.api.models.plan_type import PlanType as PlanType
from cybee_sdk.api.models.pre_post_run_script import PrePostRunScript as PrePostRunScript
from cybee_sdk.api.models.pyd_generic_message import PydGenericMessage as PydGenericMessage
from cybee_sdk.api.models.pyd_message_type import PydMessageType as PydMessageType
from cybee_sdk.api.models.repository import Repository as Repository
from cybee_sdk.api.models.repository_checks import RepositoryChecks as RepositoryChecks
from cybee_sdk.api.models.repository_create import RepositoryCreate as RepositoryCreate
from cybee_sdk.api.models.repository_maintenance import RepositoryMaintenance as RepositoryMaintenance
from cybee_sdk.api.models.repository_maintenance_create_update import (
    RepositoryMaintenanceCreateUpdate as RepositoryMaintenanceCreateUpdate,
)
from cybee_sdk.api.models.repository_prunes import RepositoryPrunes as RepositoryPrunes
from cybee_sdk.api.models.repository_stats import RepositoryStats as RepositoryStats
from cybee_sdk.api.models.repository_status_enum import RepositoryStatusEnum as RepositoryStatusEnum
from cybee_sdk.api.models.repository_update import RepositoryUpdate as RepositoryUpdate
from cybee_sdk.api.models.restic_backup_input import ResticBackupInput as ResticBackupInput
from cybee_sdk.api.models.restic_backup_output import ResticBackupOutput as ResticBackupOutput
from cybee_sdk.api.models.restic_restore import ResticRestore as ResticRestore
from cybee_sdk.api.models.restic_stats_mode_enum import ResticStatsModeEnum as ResticStatsModeEnum
from cybee_sdk.api.models.restic_version_enum import ResticVersionEnum as ResticVersionEnum
from cybee_sdk.api.models.restoration_error import RestorationError as RestorationError
from cybee_sdk.api.models.restoration_info import RestorationInfo as RestorationInfo
from cybee_sdk.api.models.restoration_status import RestorationStatus as RestorationStatus
from cybee_sdk.api.models.restoration_summary import RestorationSummary as RestorationSummary
from cybee_sdk.api.models.restore_notification_filter_input import (
    RestoreNotificationFilterInput as RestoreNotificationFilterInput,
)
from cybee_sdk.api.models.restore_notification_filter_output import (
    RestoreNotificationFilterOutput as RestoreNotificationFilterOutput,
)
from cybee_sdk.api.models.restore_plan_error import RestorePlanError as RestorePlanError
from cybee_sdk.api.models.restore_plan_run import RestorePlanRun as RestorePlanRun
from cybee_sdk.api.models.restore_summary import RestoreSummary as RestoreSummary
from cybee_sdk.api.models.restore_verbose_status import RestoreVerboseStatus as RestoreVerboseStatus
from cybee_sdk.api.models.retention_settings import RetentionSettings as RetentionSettings
from cybee_sdk.api.models.router import Router as Router
from cybee_sdk.api.models.router_create import RouterCreate as RouterCreate
from cybee_sdk.api.models.router_update import RouterUpdate as RouterUpdate
from cybee_sdk.api.models.s3_provider import S3Provider as S3Provider
from cybee_sdk.api.models.s3_signature_version_enum import S3SignatureVersionEnum as S3SignatureVersionEnum
from cybee_sdk.api.models.s3_storage_account_config import S3StorageAccountConfig as S3StorageAccountConfig
from cybee_sdk.api.models.scheduling import Scheduling as Scheduling
from cybee_sdk.api.models.scheduling_linked_plans import SchedulingLinkedPlans as SchedulingLinkedPlans
from cybee_sdk.api.models.snapshot import Snapshot as Snapshot
from cybee_sdk.api.models.storage_account import StorageAccount as StorageAccount
from cybee_sdk.api.models.storage_account_create import StorageAccountCreate as StorageAccountCreate
from cybee_sdk.api.models.storage_account_update import StorageAccountUpdate as StorageAccountUpdate
from cybee_sdk.api.models.storage_destination import StorageDestination as StorageDestination
from cybee_sdk.api.models.storage_destination_config import StorageDestinationConfig as StorageDestinationConfig
from cybee_sdk.api.models.storage_destination_create import StorageDestinationCreate as StorageDestinationCreate
from cybee_sdk.api.models.storage_destination_update import StorageDestinationUpdate as StorageDestinationUpdate
from cybee_sdk.api.models.storage_format import StorageFormat as StorageFormat
from cybee_sdk.api.models.storage_notification_filter import StorageNotificationFilter as StorageNotificationFilter
from cybee_sdk.api.models.template import Template as Template
from cybee_sdk.api.models.template_create import TemplateCreate as TemplateCreate
from cybee_sdk.api.models.time_stamps import TimeStamps as TimeStamps
from cybee_sdk.api.models.unregistered_agent_info import UnregisteredAgentInfo as UnregisteredAgentInfo
from cybee_sdk.api.models.update_scheduling import UpdateScheduling as UpdateScheduling
from cybee_sdk.api.models.validation_error import ValidationError as ValidationError
from cybee_sdk.api.models.zitadel_api_key_type import ZitadelApiKeyType as ZitadelApiKeyType
